@@ -31,3 +31,15 @@ class ConfigurationError(ThothCommonException):
 
 class WorkflowError(ThothCommonException):
     """Raised on workflow related issues."""
+
+
+class NotKnownThothIntegration(ThothCommonException):
+    """An exception raised if the given integration is not known to Thoth."""
+
+
+class QebHwtInputsMissing(ThothCommonException):
+    """An exception raised if there are inputs missing for QebHwt Github App."""
+
+
+class SolverNameParseError(ThothCommonException):
+    """Raised if unable to determine solver information out of solver name run."""
